@@ -1,9 +1,10 @@
 #' @import ggplot2
 #' @import vctrs
 #' @importFrom stats qnorm as.formula model.frame
-#' @importFrom tibble obj_sum type_sum
+#' @importFrom tibble obj_sum type_sum tbl_sum size_sum
 #' @importFrom dplyr dplyr_reconstruct
-#'
+#' @importFrom lifecycle deprecated
+
 utils::globalVariables(
    c(".config", ".estimator", ".metric", "info", "metric", "mod_nm",
      "model", "n", "pp_nm", "preprocessor", "preproc", "object",
@@ -13,30 +14,6 @@ utils::globalVariables(
 
 # ------------------------------------------------------------------------------
 
-#' @importFrom tibble tbl_sum
-#' @export
-tibble::tbl_sum
-
-#' @importFrom tibble type_sum
-#' @export
-tibble::type_sum
-
-#' @importFrom tibble size_sum
-#' @export
-tibble::size_sum
-
-#' @importFrom tune tune_grid
-#' @export
-tune::tune_grid
-
-#' @importFrom tune tune_bayes
-#' @export
-tune::tune_bayes
-
-#' @importFrom tune fit_resamples
-#' @export
-tune::fit_resamples
-
 #' @importFrom tune collect_metrics
 #' @export
 tune::collect_metrics
@@ -52,3 +29,33 @@ dplyr::`%>%`
 #' @importFrom ggplot2 autoplot
 #' @export
 ggplot2::autoplot
+
+#' @importFrom hardhat extract_spec_parsnip
+#' @export
+hardhat::extract_spec_parsnip
+#'
+#' @importFrom hardhat extract_recipe
+#' @export
+hardhat::extract_recipe
+#'
+#' @importFrom hardhat extract_fit_parsnip
+#' @export
+hardhat::extract_fit_parsnip
+#'
+#' @importFrom hardhat extract_fit_engine
+#' @export
+hardhat::extract_fit_engine
+#'
+#' @importFrom hardhat extract_mold
+#' @export
+hardhat::extract_mold
+#'
+#' @importFrom hardhat extract_preprocessor
+#' @export
+hardhat::extract_preprocessor
+#'
+#' @importFrom hardhat extract_workflow
+#' @export
+hardhat::extract_workflow
+
+
