@@ -1,10 +1,17 @@
 #' Extract elements from a workflow set
 #'
+#' `r lifecycle::badge("soft-deprecated")`
+#'
 #' `pull_workflow_set_result()` retrieves the results of [workflow_map()] for a
 #' particular workflow while `pull_workflow()` extracts the unfitted workflow
 #' from the `info` column.
+#'
+#'
 #' @param x A workflow set.
 #' @param id A single character string for a workflow ID.
+#' @details
+#' The [extract_workflow_set_result()] and [extract_workflow()] functions should
+#' be used instead of these functions.
 #' @return `pull_workflow_set_result()` produces a `tune_result` or
 #' `resample_results` object. `pull_workflow()` returns an unfit workflow
 #' object.
@@ -16,6 +23,9 @@
 #' pull_workflow(two_class_res, "none_cart")
 #' @export
 pull_workflow_set_result <- function(x, id) {
+   lifecycle::deprecate_soft("0.1.0",
+                             "pull_workflow_set_result()",
+                             "extract_workflow_set_result()")
    if (length(id) != 1) {
       rlang::abort("'id' should have a single value.")
    }
@@ -29,6 +39,7 @@ pull_workflow_set_result <- function(x, id) {
 #' @export
 #' @rdname pull_workflow_set_result
 pull_workflow <- function(x, id) {
+   lifecycle::deprecate_soft("0.1.0", "pull_workflow()", "extract_worklfow()")
    if (length(id) != 1) {
       rlang::abort("'id' should have a single value.")
    }
