@@ -2,7 +2,7 @@
 #'
 #' `workflow_map()` will execute the same function across the workflows in the
 #' set. The various `tune_*()` functions can be used as well as
-#' `fit_resamples()`.
+#' [tune::fit_resamples()].
 #' @param object A workflow set.
 #' @param fn The function to run. Acceptable values are: [tune::tune_grid()],
 #' [tune::tune_bayes()], [tune::fit_resamples()], `finetune::tune_race_anova()`,
@@ -15,7 +15,7 @@
 #' the results will be added to the `result` column. If the computations for a
 #' workflow fail, an `try-catch` object will be saved in place of the results
 #' (without stopping execution).
-#' @seealso [workflow_set()], [as_workflow_set()], [pull_workflow_set_result()]
+#' @seealso [workflow_set()], [as_workflow_set()], [extract_workflow_set_result()]
 #' @details
 #'
 #' When passing options, anything passed in the `...` will be combined with any
@@ -53,7 +53,7 @@ workflow_map <- function(object, fn = "tune_grid", verbose = FALSE,
 
    on.exit({
       cols <- tune::get_tune_colors()
-      message(cols$symbol$danger("Execution stepped; returning current results"))
+      message(cols$symbol$danger("Execution stopped; returning current results"))
       return(new_workflow_set(object))
       })
 
@@ -72,7 +72,7 @@ workflow_map <- function(object, fn = "tune_grid", verbose = FALSE,
    # new fingerprinting option.
 
    for (iter in iter_seq) {
-      wflow <- pull_workflow(object, object$wflow_id[[iter]])
+      wflow <- extract_workflow(object, object$wflow_id[[iter]])
       .fn <- check_fn(fn, wflow, verbose)
       .fn_info <- dplyr::filter(allowed_fn, func == .fn)
 
